@@ -23,10 +23,7 @@ License: GPLv2
 """
 
 import gconf
-import gettext
 import os
-from os.path import exists, dirname, realpath
-import defs
 from client import Storage
 from xdg.BaseDirectory import xdg_data_home
 import logging
@@ -37,10 +34,10 @@ import logging
 log = logging.getLogger("configuration")
 
 class Singleton(object):
-     def __new__(cls, *args, **kwargs):
-         if '__instance' not in vars(cls):
-             cls.__instance = object.__new__(cls, *args, **kwargs)
-         return cls.__instance
+    def __new__(cls, *args, **kwargs):
+        if '__instance' not in vars(cls):
+            cls.__instance = object.__new__(cls, *args, **kwargs)
+        return cls.__instance
 
 class RuntimeStore(Singleton):
     """
@@ -50,34 +47,39 @@ class RuntimeStore(Singleton):
     database_file = None
     last_etag = None
     data_dir = ""
+    home_data_dir = ""
     storage = None
     conf = None
 
 
     def __init__(self):
-        gettext.install("hamster-applet", unicode = True)
-
-        # Makefile.in shouldn't be in the final install
-        module_dir = dirname(realpath(__file__))
-        if exists(os.path.join(module_dir, "Makefile")):
-            self.data_dir = os.path.join(module_dir, '..', '..', 'data')
-        else:
+        try:
+            import defs
             self.data_dir = os.path.join(defs.DATA_DIR, "hamster-applet")
+            self.version = defs.VERSION
+        except:
+            # if defs is not there, we are running from sources
+            module_dir = os.path.dirname(os.path.realpath(__file__))
+            self.data_dir = os.path.join(module_dir, '..', '..', 'data')
+            self.version = "uninstalled"
+
+        self.data_dir = os.path.realpath(self.data_dir)
+        self.home_data_dir = os.path.realpath(os.path.join(xdg_data_home, "hamster-applet"))
+
+        if not os.path.exists(self.home_data_dir):
+            try:
+                os.makedirs(self.home_data_dir, 0744)
+            except Exception, msg:
+                logging.error("could not create user dir (%s): %s" % (self.home_data_dir, msg))
+
 
         self.storage = Storage()
-
         # figure out the correct database file
         old_db_file = os.path.expanduser("~/.gnome2/hamster-applet/hamster.db")
-        new_db_file = os.path.join(xdg_data_home, "hamster-applet", "hamster.db")
+        new_db_file = os.path.join(self.home_data_dir, "hamster.db")
 
         # move database to ~/.local/share/hamster-applet
         if os.path.exists(old_db_file):
-            db_path, _ = os.path.split(os.path.realpath(new_db_file))
-            if not os.path.exists(db_path):
-                try:
-                    os.makedirs(db_path, 0744)
-                except Exception, msg:
-                    logging.error("could not create user dir (%s): %s" % (db_path, msg))
             if os.path.exists(new_db_file):
                 logging.info("Have two database %s and %s" % (new_db_file, old_db_file))
             else:
@@ -167,24 +169,24 @@ class GConfStore(gobject.GObject, Singleton):
         'notify_on_idle'              :   False,       # Remind also if no activity is set
         'notify_interval'             :   27,          # Remind of current activity every X minutes
         'day_start_minutes'           :   5 * 60 + 30, # At what time does the day start (5:30AM)
-        'keybinding'                  :   "<Super>H",  # Key binding to summon hamster
         'overview_window_box'         :   [],          # X, Y, W, H
         'overview_window_maximized'   :   False,       # Is overview window maximized
         'workspace_tracking'          :   [],          # Should hamster switch activities on workspace change 0,1,2
         'workspace_mapping'           :   [],          # Mapping between workspace numbers and activities
         'standalone_window_box'       :   [],          # X, Y, W, H
         'standalone_window_maximized' :   False,       # Is overview window maximized
-        'activities_source'           :   "",           # Source of TODO items ("", "evo", "gtg")
+        'activities_source'           :   "",          # Source of TODO items ("", "evo", "gtg")
+        'last_report_folder'          :   "~",         # Path to directory where the last report was saved
     }
 
     __gsignals__ = {
         "conf-changed": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT, gobject.TYPE_PYOBJECT))
     }
     def __init__(self):
-          gobject.GObject.__init__(self)
-          self._client = gconf.client_get_default()
-          self._client.add_dir(self.GCONF_DIR[:-1], gconf.CLIENT_PRELOAD_RECURSIVE)
-          self._notifications = []
+        gobject.GObject.__init__(self)
+        self._client = gconf.client_get_default()
+        self._client.add_dir(self.GCONF_DIR[:-1], gconf.CLIENT_PRELOAD_RECURSIVE)
+        self._notifications = []
 
     def _fix_key(self, key):
         """
