@@ -23,6 +23,7 @@ pygtk.require('2.0')
 
 import os
 import gtk, gobject
+from .hamster.configuration import conf
 
 class ReportChooserDialog(gtk.Dialog):
     __gsignals__ = {
@@ -35,14 +36,20 @@ class ReportChooserDialog(gtk.Dialog):
         gtk.Dialog.__init__(self)
 
 
-        self.dialog = gtk.FileChooserDialog(title = _("Save Report — Time Tracker"),
+        self.dialog = gtk.FileChooserDialog(title = _(u"Save Report — Time Tracker"),
                                             parent = self,
                                             action = gtk.FILE_CHOOSER_ACTION_SAVE,
                                             buttons=(gtk.STOCK_CANCEL,
                                                      gtk.RESPONSE_CANCEL,
                                                      gtk.STOCK_SAVE,
                                                      gtk.RESPONSE_OK))
-        self.dialog.set_current_folder(os.path.expanduser("~"))
+
+        # try to set path to last known folder or fall back to home
+        report_folder = os.path.expanduser(conf.get("last_report_folder"))
+        if os.path.exists(report_folder):
+            self.dialog.set_current_folder(report_folder)
+        else:
+            self.dialog.set_current_folder(os.path.expanduser("~"))
 
         self.filters = {}
 
@@ -125,6 +132,8 @@ class ReportChooserDialog(gtk.Dialog):
 
         categories = []
 
+        conf.set("last_report_folder", os.path.dirname(path))
+
         # format, path, start_date, end_date
         self.emit("report-chosen", format, path)
         self.dialog.destroy()
